@@ -1,11 +1,4 @@
-from dataclasses import dataclass
-
-
-@dataclass(frozen=True)
-class Instance:
-    protocol: str = "http"
-    host: str = "localhost"
-    port: int = 9100
+from tamr_client._types import Instance
 
 
 def origin(instance: Instance) -> str:
@@ -13,4 +6,7 @@ def origin(instance: Instance) -> str:
 
     For additional information, see `MDN web docs <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Origin>`_ .
     """
-    return f"{instance.protocol}://{instance.host}:{instance.port}"
+    if instance.port is None:
+        return f"{instance.protocol}://{instance.host}"
+    else:
+        return f"{instance.protocol}://{instance.host}:{instance.port}"
